#' @keywords internal
"_PACKAGE"

## usethis namespace: start
## usethis namespace: end

## Suppress R CMD check NOTEs for variables used in mirai expressions
utils::globalVariables(c("seed", "data_list"))

NULL
