# RMitemInfitCutoffPlot is a deprecated alias forwarding to RMitemInfitPlot

    Code
      p <- RMitemInfitCutoffPlot(simfit)
    Condition
      Warning in `RMitemInfitCutoffPlot()`:
      'RMitemInfitCutoffPlot' is deprecated.
      Use 'RMitemInfitPlot' instead.
      See help("Deprecated")

